@@ -180,7 +180,7 @@ void Fcb::v3::PolygoneType::decode(UPERDecoder &decoder)
 
 void Fcb::v3::RegionalValidityType::decode(UPERDecoder &decoder)
 {
-    value = decoder.readChoiceWithExtensionMarker<TrainLinkType, ViaStationType, ZoneType, LineType, PolygoneType>();
+    value = decoder.readChoiceWithExtensionMarker<decltype(value)>();
 }
 
 void Fcb::v3::ReturnRouteDescriptionType::decode(UPERDecoder &decoder)
@@ -739,20 +739,7 @@ void Fcb::v3::DocumentData::decode(UPERDecoder &decoder)
 {
     decodeSequence(decoder);
     FCB_READ_CUSTOM(token);
-    ticket = decoder.readChoiceWithExtensionMarker<
-        ReservationData,
-        CarCarriageReservationData,
-        OpenTicketData,
-        PassData,
-        VoucherData,
-        CustomerCardData,
-        CountermarkData,
-        ParkingGroundData,
-        FIPTicketData,
-        StationPassageData,
-        ExtensionData,
-        DelayConfirmation
-    >();
+    ticket = decoder.readChoiceWithExtensionMarker<decltype(ticket)>();
 }
 
 void Fcb::v3::TicketLinkType::decode(UPERDecoder &decoder)
@@ -787,7 +774,7 @@ void Fcb::v3::ControlData::decode(UPERDecoder &decoder)
 Fcb::v3::UicRailTicketData::UicRailTicketData() = default;
 
 Fcb::v3::UicRailTicketData::UicRailTicketData(const Uic9183Block &block)
-    : m_block(block)
+    : m_data(QVariant::fromValue(block))
 {
     if (block.isNull()) {
         return;
@@ -796,7 +783,18 @@ Fcb::v3::UicRailTicketData::UicRailTicketData(const Uic9183Block &block)
     decode(decoder);
     if (decoder.hasError()) {
         qCWarning(Log) << decoder.errorMessage();
-        m_block = {};
+        m_data = {};
+    }
+}
+
+Fcb::v3::UicRailTicketData::UicRailTicketData(const QByteArray &data)
+    : m_data(data)
+{
+    UPERDecoder decoder(BitVectorView(std::string_view(data.constData(), data.size())));
+    decode(decoder);
+    if (decoder.hasError()) {
+        qCWarning(Log) << decoder.errorMessage();
+        m_data = {};
     }
 }
 
@@ -811,7 +809,7 @@ void Fcb::v3::UicRailTicketData::decode(UPERDecoder &decoder)
 
 bool Fcb::v3::UicRailTicketData::isValid() const
 {
-    return !m_block.isNull();
+    return !m_data.isNull();
 }
 
 #include "moc_fcbticket3.cpp"
