@@ -45,6 +45,9 @@ QVariant KITINERARY_EXPORT location(const QVariant &res);
 /** Returns the geo coordinates of a given location. */
 GeoCoordinates KITINERARY_EXPORT geo(const QVariant &location);
 
+/** Parses geo coordinates from a given mapping service URLs, such as Google Maps links. */
+GeoCoordinates KITINERARY_EXPORT geoFromUrl(const QUrl &url);
+
 /** Returns the address of the given location. */
 PostalAddress KITINERARY_EXPORT address(const QVariant &location);
 
@@ -54,7 +57,7 @@ QString KITINERARY_EXPORT name(const QVariant &location);
 /** Computes the distance between to geo coordinates in meters. */
 int KITINERARY_EXPORT distance(const GeoCoordinates &coord1, const GeoCoordinates &coord2);
 /** Computes the distance between to geo coordinates in meters. */
-int KITINERARY_EXPORT distance(float lat1, float lon1, float lat2, float lon2);
+int KITINERARY_EXPORT distance(double lat1, double lon1, double lat2, double lon2);
 
 /** Location comparison accuracy. */
 enum Accuracy {
